@@ -65,6 +65,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.ajax.SessionServlet;
 import com.openexchange.ajax.fields.Header;
+import com.openexchange.ajax.login.LoginRequestContext;
 import com.openexchange.ajax.login.LoginRequestHandler;
 import com.openexchange.authentication.LoginExceptionCodes;
 import com.openexchange.exception.OXException;
@@ -104,10 +105,14 @@ public final class KerberosTicketReload extends SessionServlet implements LoginR
     }
 
     @Override
-    public void handleRequest(HttpServletRequest req, HttpServletResponse resp) throws IOException {
+    public void handleRequest(HttpServletRequest req, HttpServletResponse resp, LoginRequestContext requestContext) throws IOException {
         try {
-            doAuthHeaderTicketReload(req, resp);
+            doAuthHeaderTicketReload(req, resp, requestContext);
+            if(requestContext.getMetricProvider().isStateUnknown()) {
+               requestContext.getMetricProvider().recordSuccess();
+            }
         } catch (OXException e) {
+            requestContext.getMetricProvider().recordException(e);
             if (SessionExceptionCodes.hasPrefix(e)) {
                 // Is a session exception
                 LOG.debug(e.getMessage(), e);
@@ -118,7 +123,7 @@ public final class KerberosTicketReload extends SessionServlet implements LoginR
         }
     }
 
-    private void doAuthHeaderTicketReload(HttpServletRequest req, HttpServletResponse resp) throws OXException, IOException {
+    private void doAuthHeaderTicketReload(HttpServletRequest req, HttpServletResponse resp, LoginRequestContext requestContext) throws OXException, IOException {
         final String sessionId = getSessionId(req);
         SessionResult<ServerSession> result = getSession(req, resp, sessionId, sessiondService);
         if (Reply.STOP == result.getReply()) {
@@ -132,11 +137,13 @@ public final class KerberosTicketReload extends SessionServlet implements LoginR
         verifySession(req, sessiondService, sessionId, session);
         if (session.containsParameter(SESSION_PRINCIPAL)) {
             resp.setStatus(HttpServletResponse.SC_NO_CONTENT);
+            requestContext.getMetricProvider().recordHTTPStatus(HttpServletResponse.SC_NO_CONTENT);
             return;
         }
         final String auth = req.getHeader(Header.AUTH_HEADER);
         if (null == auth) {
             notAuthorized(resp, "Authorization Required!");
+            requestContext.getMetricProvider().recordHTTPStatus(HttpServletResponse.SC_UNAUTHORIZED);
             return;
         }
         if (!Authorization.checkForAuthorizationHeader(auth)) {
@@ -154,6 +161,7 @@ public final class KerberosTicketReload extends SessionServlet implements LoginR
             // Is thrown if the ticket is no longer valid. See bug 35182.
             LOG.error(e.getMessage(), e);
             notAuthorized(resp, e.getMessage());
+            requestContext.getMetricProvider().recordHTTPStatus(HttpServletResponse.SC_UNAUTHORIZED);
             return;
         }
         session.setParameter(SESSION_SUBJECT, principal.getDelegateSubject());
